<?php
/**
 * @file
 * Administration settings page for entity iframe.
 */

/**
 * Implements hook_admin_settings().
 */
function entity_iframe_admin_settings() {
  $form = array();
  $themes = array();
  $theme_list = system_rebuild_theme_data();
  foreach ($theme_list as &$theme) {
    if (!empty($theme->info['hidden'])) {
      continue;
    }
    $themes[$theme->name] = $theme->info['name'];
  }
  $form['entity_iframe_theme'] = array(
    '#type' => 'select',
    '#title' => t('Default iframe theme'),
    '#description' => t('Theme to use when its in iframe'),
    '#default_value' => variable_get('entity_iframe_theme', ENTITY_IFRAME_THEME),
    '#options' => $themes,
  );
  $options = _entity_iframe_entity_types();
  $form['entity_iframe_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Entity types'),
    '#description' => t('Show on these entity types.'),
    '#multiple' => TRUE,
    '#options' => $options,
    '#default_value' => variable_get('entity_iframe_types', array_keys($options)),
  );
  $form['entity_iframe_link'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add Link on entity view'),
    '#description' => t('Show a shortcut link on entity view.'),
    '#default_value' => variable_get('entity_iframe_link', ENTITY_IFRAME_LINK),
  );
  $form['entity_iframe'] = array(
    '#type' => 'fieldset',
    '#title' => t('iframe embed'),
    '#description' => t('Customize the embedded iframe if enabled'),
    '#collapsible' => FALSE,
  );
  $form['entity_iframe']['entity_iframe_embed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Embed code'),
    '#description' => t('Show iframe embed code on entity view.'),
    '#default_value' => variable_get('entity_iframe_embed', ENTITY_IFRAME_EMBED),
  );
  $form['entity_iframe']['entity_iframe_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Width'),
    '#description' => t('Default width for the embed code.'),
    '#default_value' => variable_get('entity_iframe_width', ENTITY_IFRAME_WIDTH),
    '#states' => array(
      'visible' => array(
        array(':input[name="entity_iframe_embed"]' => array('checked' => TRUE)),
      ),
    ),
  );
  $form['entity_iframe']['entity_iframe_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#description' => t('Default height for the embed code.'),
    '#default_value' => variable_get('entity_iframe_height', ENTITY_IFRAME_HEIGHT),
    '#states' => array(
      'visible' => array(
        array(':input[name="entity_iframe_embed"]' => array('checked' => TRUE)),
      ),
    ),
  );
  $form['#submit'][] = 'entity_iframe_admin_settings_submit';
  return system_settings_form($form);
}

/**
 * Form callback for admin_settings.
 */
function entity_iframe_admin_settings_submit($form, &$form_state) {
  // make sure the admin theme is enabled
  $theme = $form_state['values']['entity_iframe_theme'];
  if (!_entity_iframe_theme_exists($theme)) {
    theme_enable(array($theme));
  }
}